@@ -65,6 +65,12 @@ The packages may also be specified by their entire URL,
 e.g.`https://repo.continuum.io/pkgs/free/osx-64/openssl-1.0.1k-1.tar.bz2`.
 Optionally, the MD5 hash sum of the package, may be added after an immediate
 `#` character, e.g. `readline-6.2-2.tar.bz2#0801e644bd0c1cd7f0923b56c52eb7f7`.
+'''),
+
+    ('menu_packages',           False, list, '''
+Packages for menu items will be installed (if the conda package contains the
+necessary metadata in "Menu/<package name>.json").  Menu items are currently
+only supported on Windows.  By default, all menu items will be installed.
 '''),
 
     ('install_in_dependency_order', False, bool, '''
@@ -203,6 +209,12 @@ def verify(info):
             sys.exit("Error: Required key '%s' not found in construct.yaml" %
                      key)
 
+    pat = re.compile(r'[\w][\w\-\.]*$')
+    for key in 'name', 'version':
+        value = info[key]
+        if not pat.match(value) or value.endswith(('.', '-')):
+            sys.exit("Error: invalid %s '%s'" % (key, value))
+
 
 def generate_doc():
     path = abspath('%s/../../CONSTRUCT.md' % __file__)
