@@ -125,6 +125,7 @@ def show(info):
     print("""
 name: %(name)s
 version: %(version)s
+cache download location: %(_download_dir)s
 platform: %(_platform)s""" % info)
     print("number of package: %d" % len(dists))
     for fn in dists:
@@ -189,6 +190,11 @@ def main(info, verbose=True):
         dists.sort()
     move_python_first()
 
+    all_names = set(name_dist(fn) for fn in dists)
+    for name in info.get('menu_packages', []):
+        if name not in all_names:
+            print("WARNING: no such package (in menu_packages): %s" % name)
+
     if verbose:
         show(info)
     check_dists()
